lance_
encoding_
datafusion
0.19.2
Module zone
Module Items
Structs
In crate lance_
encoding_
datafusion
lance_encoding_datafusion
Module
zone
Structs

Unloaded
Pushdown
Extracted pushdown information obtained from the column encoding description.
Zone
Maps
Field
Encoder
A field encoder that creates zone maps for the data it encodes
Zone
Maps
Field
Scheduler
A top level scheduler that refines the requested range based on pushdown filtering with zone maps