pub struct UnloadedPushdown { /* private fields */ }Expand description
Extracted pushdown information obtained from the column encoding description.
This is “unloaded” because we haven’t yet loaded the actual zone maps from the file (though position and size tell us where they are)